## Features

 - Self-contained. No dependencies other than a recent Python implementation.
 - 100% test coverage
 - Static type checked
 - Linted

## Why

 - Did the phone company did their math right?
 - Your complaint will be resolved within 12 days. Okay, when is that?
 - Oh, my birthday was 3 months ago.
 - My friend's wedding anniversary is 2 weeks away.

## What can't be done

 - Subtracting a date from an offset.
   + `3d - 2021/04/28  # will throw error`
 - 
